#[cfg(feature = "cc430f5123")]
pub mod cc430f5123;
#[cfg(feature = "cc430f5125")]
pub mod cc430f5125;
#[cfg(feature = "cc430f5133")]
pub mod cc430f5133;
#[cfg(feature = "cc430f5135")]
pub mod cc430f5135;
#[cfg(feature = "cc430f5137")]
pub mod cc430f5137;
#[cfg(feature = "cc430f5143")]
pub mod cc430f5143;
#[cfg(feature = "cc430f5145")]
pub mod cc430f5145;
#[cfg(feature = "cc430f5147")]
pub mod cc430f5147;
#[cfg(feature = "cc430f6125")]
pub mod cc430f6125;
#[cfg(feature = "cc430f6126")]
pub mod cc430f6126;
#[cfg(feature = "cc430f6127")]
pub mod cc430f6127;
#[cfg(feature = "cc430f6135")]
pub mod cc430f6135;
#[cfg(feature = "cc430f6137")]
pub mod cc430f6137;
#[cfg(feature = "cc430f6143")]
pub mod cc430f6143;
#[cfg(feature = "cc430f6145")]
pub mod cc430f6145;
#[cfg(feature = "cc430f6147")]
pub mod cc430f6147;
#[cfg(feature = "msp430afe221")]
pub mod msp430afe221;
#[cfg(feature = "msp430afe222")]
pub mod msp430afe222;
#[cfg(feature = "msp430afe223")]
pub mod msp430afe223;
#[cfg(feature = "msp430afe231")]
pub mod msp430afe231;
#[cfg(feature = "msp430afe232")]
pub mod msp430afe232;
#[cfg(feature = "msp430afe233")]
pub mod msp430afe233;
#[cfg(feature = "msp430afe251")]
pub mod msp430afe251;
#[cfg(feature = "msp430afe252")]
pub mod msp430afe252;
#[cfg(feature = "msp430afe253")]
pub mod msp430afe253;
#[cfg(feature = "msp430bt5190")]
pub mod msp430bt5190;
#[cfg(feature = "msp430c091")]
pub mod msp430c091;
#[cfg(feature = "msp430c092")]
pub mod msp430c092;
#[cfg(feature = "msp430c111")]
pub mod msp430c111;
#[cfg(feature = "msp430c1111")]
pub mod msp430c1111;
#[cfg(feature = "msp430c112")]
pub mod msp430c112;
#[cfg(feature = "msp430c1121")]
pub mod msp430c1121;
#[cfg(feature = "msp430c1331")]
pub mod msp430c1331;
#[cfg(feature = "msp430c1351")]
pub mod msp430c1351;
#[cfg(feature = "msp430c311s")]
pub mod msp430c311s;
#[cfg(feature = "msp430c312")]
pub mod msp430c312;
#[cfg(feature = "msp430c313")]
pub mod msp430c313;
#[cfg(feature = "msp430c314")]
pub mod msp430c314;
#[cfg(feature = "msp430c315")]
pub mod msp430c315;
#[cfg(feature = "msp430c323")]
pub mod msp430c323;
#[cfg(feature = "msp430c325")]
pub mod msp430c325;
#[cfg(feature = "msp430c336")]
pub mod msp430c336;
#[cfg(feature = "msp430c337")]
pub mod msp430c337;
#[cfg(feature = "msp430c412")]
pub mod msp430c412;
#[cfg(feature = "msp430c413")]
pub mod msp430c413;
#[cfg(feature = "msp430cg4616")]
pub mod msp430cg4616;
#[cfg(feature = "msp430cg4617")]
pub mod msp430cg4617;
#[cfg(feature = "msp430cg4618")]
pub mod msp430cg4618;
#[cfg(feature = "msp430cg4619")]
pub mod msp430cg4619;
#[cfg(feature = "msp430e112")]
pub mod msp430e112;
#[cfg(feature = "msp430e313")]
pub mod msp430e313;
#[cfg(feature = "msp430e315")]
pub mod msp430e315;
#[cfg(feature = "msp430e325")]
pub mod msp430e325;
#[cfg(feature = "msp430e337")]
pub mod msp430e337;
#[cfg(feature = "msp430f110")]
pub mod msp430f110;
#[cfg(feature = "msp430f1101")]
pub mod msp430f1101;
#[cfg(feature = "msp430f1101a")]
pub mod msp430f1101a;
#[cfg(feature = "msp430f1111")]
pub mod msp430f1111;
#[cfg(feature = "msp430f1111a")]
pub mod msp430f1111a;
#[cfg(feature = "msp430f112")]
pub mod msp430f112;
#[cfg(feature = "msp430f1121")]
pub mod msp430f1121;
#[cfg(feature = "msp430f1121a")]
pub mod msp430f1121a;
#[cfg(feature = "msp430f1122")]
pub mod msp430f1122;
#[cfg(feature = "msp430f1132")]
pub mod msp430f1132;
#[cfg(feature = "msp430f122")]
pub mod msp430f122;
#[cfg(feature = "msp430f1222")]
pub mod msp430f1222;
#[cfg(feature = "msp430f123")]
pub mod msp430f123;
#[cfg(feature = "msp430f1232")]
pub mod msp430f1232;
#[cfg(feature = "msp430f133")]
pub mod msp430f133;
#[cfg(feature = "msp430f135")]
pub mod msp430f135;
#[cfg(feature = "msp430f147")]
pub mod msp430f147;
#[cfg(feature = "msp430f1471")]
pub mod msp430f1471;
#[cfg(feature = "msp430f148")]
pub mod msp430f148;
#[cfg(feature = "msp430f1481")]
pub mod msp430f1481;
#[cfg(feature = "msp430f149")]
pub mod msp430f149;
#[cfg(feature = "msp430f1491")]
pub mod msp430f1491;
#[cfg(feature = "msp430f155")]
pub mod msp430f155;
#[cfg(feature = "msp430f156")]
pub mod msp430f156;
#[cfg(feature = "msp430f157")]
pub mod msp430f157;
#[cfg(feature = "msp430f1610")]
pub mod msp430f1610;
#[cfg(feature = "msp430f1611")]
pub mod msp430f1611;
#[cfg(feature = "msp430f1612")]
pub mod msp430f1612;
#[cfg(feature = "msp430f167")]
pub mod msp430f167;
#[cfg(feature = "msp430f168")]
pub mod msp430f168;
#[cfg(feature = "msp430f169")]
pub mod msp430f169;
#[cfg(feature = "msp430f2001")]
pub mod msp430f2001;
#[cfg(feature = "msp430f2002")]
pub mod msp430f2002;
#[cfg(feature = "msp430f2003")]
pub mod msp430f2003;
#[cfg(feature = "msp430f2011")]
pub mod msp430f2011;
#[cfg(feature = "msp430f2012")]
pub mod msp430f2012;
#[cfg(feature = "msp430f2013")]
pub mod msp430f2013;
#[cfg(feature = "msp430f2101")]
pub mod msp430f2101;
#[cfg(feature = "msp430f2111")]
pub mod msp430f2111;
#[cfg(feature = "msp430f2112")]
pub mod msp430f2112;
#[cfg(feature = "msp430f2121")]
pub mod msp430f2121;
#[cfg(feature = "msp430f2122")]
pub mod msp430f2122;
#[cfg(feature = "msp430f2131")]
pub mod msp430f2131;
#[cfg(feature = "msp430f2132")]
pub mod msp430f2132;
#[cfg(feature = "msp430f2232")]
pub mod msp430f2232;
#[cfg(feature = "msp430f2234")]
pub mod msp430f2234;
#[cfg(feature = "msp430f2252")]
pub mod msp430f2252;
#[cfg(feature = "msp430f2254")]
pub mod msp430f2254;
#[cfg(feature = "msp430f2272")]
pub mod msp430f2272;
#[cfg(feature = "msp430f2274")]
pub mod msp430f2274;
#[cfg(feature = "msp430f233")]
pub mod msp430f233;
#[cfg(feature = "msp430f2330")]
pub mod msp430f2330;
#[cfg(feature = "msp430f235")]
pub mod msp430f235;
#[cfg(feature = "msp430f2350")]
pub mod msp430f2350;
#[cfg(feature = "msp430f2370")]
pub mod msp430f2370;
#[cfg(feature = "msp430f2410")]
pub mod msp430f2410;
#[cfg(feature = "msp430f2416")]
pub mod msp430f2416;
#[cfg(feature = "msp430f2417")]
pub mod msp430f2417;
#[cfg(feature = "msp430f2418")]
pub mod msp430f2418;
#[cfg(feature = "msp430f2419")]
pub mod msp430f2419;
#[cfg(feature = "msp430f247")]
pub mod msp430f247;
#[cfg(feature = "msp430f2471")]
pub mod msp430f2471;
#[cfg(feature = "msp430f248")]
pub mod msp430f248;
#[cfg(feature = "msp430f2481")]
pub mod msp430f2481;
#[cfg(feature = "msp430f249")]
pub mod msp430f249;
#[cfg(feature = "msp430f2491")]
pub mod msp430f2491;
#[cfg(feature = "msp430f2616")]
pub mod msp430f2616;
#[cfg(feature = "msp430f2617")]
pub mod msp430f2617;
#[cfg(feature = "msp430f2618")]
pub mod msp430f2618;
#[cfg(feature = "msp430f2619")]
pub mod msp430f2619;
#[cfg(feature = "msp430f412")]
pub mod msp430f412;
#[cfg(feature = "msp430f413")]
pub mod msp430f413;
#[cfg(feature = "msp430f4132")]
pub mod msp430f4132;
#[cfg(feature = "msp430f415")]
pub mod msp430f415;
#[cfg(feature = "msp430f4152")]
pub mod msp430f4152;
#[cfg(feature = "msp430f417")]
pub mod msp430f417;
#[cfg(feature = "msp430f423")]
pub mod msp430f423;
#[cfg(feature = "msp430f423a")]
pub mod msp430f423a;
#[cfg(feature = "msp430f425")]
pub mod msp430f425;
#[cfg(feature = "msp430f4250")]
pub mod msp430f4250;
#[cfg(feature = "msp430f425a")]
pub mod msp430f425a;
#[cfg(feature = "msp430f4260")]
pub mod msp430f4260;
#[cfg(feature = "msp430f427")]
pub mod msp430f427;
#[cfg(feature = "msp430f4270")]
pub mod msp430f4270;
#[cfg(feature = "msp430f427a")]
pub mod msp430f427a;
#[cfg(feature = "msp430f435")]
pub mod msp430f435;
#[cfg(feature = "msp430f4351")]
pub mod msp430f4351;
#[cfg(feature = "msp430f436")]
pub mod msp430f436;
#[cfg(feature = "msp430f4361")]
pub mod msp430f4361;
#[cfg(feature = "msp430f437")]
pub mod msp430f437;
#[cfg(feature = "msp430f4371")]
pub mod msp430f4371;
#[cfg(feature = "msp430f438")]
pub mod msp430f438;
#[cfg(feature = "msp430f439")]
pub mod msp430f439;
#[cfg(feature = "msp430f447")]
pub mod msp430f447;
#[cfg(feature = "msp430f448")]
pub mod msp430f448;
#[cfg(feature = "msp430f4481")]
pub mod msp430f4481;
#[cfg(feature = "msp430f449")]
pub mod msp430f449;
#[cfg(feature = "msp430f4491")]
pub mod msp430f4491;
#[cfg(feature = "msp430f4616")]
pub mod msp430f4616;
#[cfg(feature = "msp430f46161")]
pub mod msp430f46161;
#[cfg(feature = "msp430f4617")]
pub mod msp430f4617;
#[cfg(feature = "msp430f46171")]
pub mod msp430f46171;
#[cfg(feature = "msp430f4618")]
pub mod msp430f4618;
#[cfg(feature = "msp430f46181")]
pub mod msp430f46181;
#[cfg(feature = "msp430f4619")]
pub mod msp430f4619;
#[cfg(feature = "msp430f46191")]
pub mod msp430f46191;
#[cfg(feature = "msp430f47126")]
pub mod msp430f47126;
#[cfg(feature = "msp430f47127")]
pub mod msp430f47127;
#[cfg(feature = "msp430f47163")]
pub mod msp430f47163;
#[cfg(feature = "msp430f47166")]
pub mod msp430f47166;
#[cfg(feature = "msp430f47167")]
pub mod msp430f47167;
#[cfg(feature = "msp430f47173")]
pub mod msp430f47173;
#[cfg(feature = "msp430f47176")]
pub mod msp430f47176;
#[cfg(feature = "msp430f47177")]
pub mod msp430f47177;
#[cfg(feature = "msp430f47183")]
pub mod msp430f47183;
#[cfg(feature = "msp430f47186")]
pub mod msp430f47186;
#[cfg(feature = "msp430f47187")]
pub mod msp430f47187;
#[cfg(feature = "msp430f47193")]
pub mod msp430f47193;
#[cfg(feature = "msp430f47196")]
pub mod msp430f47196;
#[cfg(feature = "msp430f47197")]
pub mod msp430f47197;
#[cfg(feature = "msp430f477")]
pub mod msp430f477;
#[cfg(feature = "msp430f478")]
pub mod msp430f478;
#[cfg(feature = "msp430f4783")]
pub mod msp430f4783;
#[cfg(feature = "msp430f4784")]
pub mod msp430f4784;
#[cfg(feature = "msp430f479")]
pub mod msp430f479;
#[cfg(feature = "msp430f4793")]
pub mod msp430f4793;
#[cfg(feature = "msp430f4794")]
pub mod msp430f4794;
#[cfg(feature = "msp430f5131")]
pub mod msp430f5131;
#[cfg(feature = "msp430f5132")]
pub mod msp430f5132;
#[cfg(feature = "msp430f5151")]
pub mod msp430f5151;
#[cfg(feature = "msp430f5152")]
pub mod msp430f5152;
#[cfg(feature = "msp430f5171")]
pub mod msp430f5171;
#[cfg(feature = "msp430f5172")]
pub mod msp430f5172;
#[cfg(feature = "msp430f5212")]
pub mod msp430f5212;
#[cfg(feature = "msp430f5213")]
pub mod msp430f5213;
#[cfg(feature = "msp430f5214")]
pub mod msp430f5214;
#[cfg(feature = "msp430f5217")]
pub mod msp430f5217;
#[cfg(feature = "msp430f5218")]
pub mod msp430f5218;
#[cfg(feature = "msp430f5219")]
pub mod msp430f5219;
#[cfg(feature = "msp430f5222")]
pub mod msp430f5222;
#[cfg(feature = "msp430f5223")]
pub mod msp430f5223;
#[cfg(feature = "msp430f5224")]
pub mod msp430f5224;
#[cfg(feature = "msp430f5227")]
pub mod msp430f5227;
#[cfg(feature = "msp430f5228")]
pub mod msp430f5228;
#[cfg(feature = "msp430f5229")]
pub mod msp430f5229;
#[cfg(feature = "msp430f5232")]
pub mod msp430f5232;
#[cfg(feature = "msp430f5234")]
pub mod msp430f5234;
#[cfg(feature = "msp430f5237")]
pub mod msp430f5237;
#[cfg(feature = "msp430f5239")]
pub mod msp430f5239;
#[cfg(feature = "msp430f5242")]
pub mod msp430f5242;
#[cfg(feature = "msp430f5244")]
pub mod msp430f5244;
#[cfg(feature = "msp430f5247")]
pub mod msp430f5247;
#[cfg(feature = "msp430f5249")]
pub mod msp430f5249;
#[cfg(feature = "msp430f5252")]
pub mod msp430f5252;
#[cfg(feature = "msp430f5253")]
pub mod msp430f5253;
#[cfg(feature = "msp430f5254")]
pub mod msp430f5254;
#[cfg(feature = "msp430f5255")]
pub mod msp430f5255;
#[cfg(feature = "msp430f5256")]
pub mod msp430f5256;
#[cfg(feature = "msp430f5257")]
pub mod msp430f5257;
#[cfg(feature = "msp430f5258")]
pub mod msp430f5258;
#[cfg(feature = "msp430f5259")]
pub mod msp430f5259;
#[cfg(feature = "msp430f5304")]
pub mod msp430f5304;
#[cfg(feature = "msp430f5308")]
pub mod msp430f5308;
#[cfg(feature = "msp430f5309")]
pub mod msp430f5309;
#[cfg(feature = "msp430f5310")]
pub mod msp430f5310;
#[cfg(feature = "msp430f5324")]
pub mod msp430f5324;
#[cfg(feature = "msp430f5325")]
pub mod msp430f5325;
#[cfg(feature = "msp430f5326")]
pub mod msp430f5326;
#[cfg(feature = "msp430f5327")]
pub mod msp430f5327;
#[cfg(feature = "msp430f5328")]
pub mod msp430f5328;
#[cfg(feature = "msp430f5329")]
pub mod msp430f5329;
#[cfg(feature = "msp430f5333")]
pub mod msp430f5333;
#[cfg(feature = "msp430f5335")]
pub mod msp430f5335;
#[cfg(feature = "msp430f5336")]
pub mod msp430f5336;
#[cfg(feature = "msp430f5338")]
pub mod msp430f5338;
#[cfg(feature = "msp430f5340")]
pub mod msp430f5340;
#[cfg(feature = "msp430f5341")]
pub mod msp430f5341;
#[cfg(feature = "msp430f5342")]
pub mod msp430f5342;
#[cfg(feature = "msp430f5358")]
pub mod msp430f5358;
#[cfg(feature = "msp430f5359")]
pub mod msp430f5359;
#[cfg(feature = "msp430f5418")]
pub mod msp430f5418;
#[cfg(feature = "msp430f5418a")]
pub mod msp430f5418a;
#[cfg(feature = "msp430f5419")]
pub mod msp430f5419;
#[cfg(feature = "msp430f5419a")]
pub mod msp430f5419a;
#[cfg(feature = "msp430f5435")]
pub mod msp430f5435;
#[cfg(feature = "msp430f5435a")]
pub mod msp430f5435a;
#[cfg(feature = "msp430f5436")]
pub mod msp430f5436;
#[cfg(feature = "msp430f5436a")]
pub mod msp430f5436a;
#[cfg(feature = "msp430f5437")]
pub mod msp430f5437;
#[cfg(feature = "msp430f5437a")]
pub mod msp430f5437a;
#[cfg(feature = "msp430f5438")]
pub mod msp430f5438;
#[cfg(feature = "msp430f5438a")]
pub mod msp430f5438a;
#[cfg(feature = "msp430f5500")]
pub mod msp430f5500;
#[cfg(feature = "msp430f5501")]
pub mod msp430f5501;
#[cfg(feature = "msp430f5502")]
pub mod msp430f5502;
#[cfg(feature = "msp430f5503")]
pub mod msp430f5503;
#[cfg(feature = "msp430f5504")]
pub mod msp430f5504;
#[cfg(feature = "msp430f5505")]
pub mod msp430f5505;
#[cfg(feature = "msp430f5506")]
pub mod msp430f5506;
#[cfg(feature = "msp430f5507")]
pub mod msp430f5507;
#[cfg(feature = "msp430f5508")]
pub mod msp430f5508;
#[cfg(feature = "msp430f5509")]
pub mod msp430f5509;
#[cfg(feature = "msp430f5510")]
pub mod msp430f5510;
#[cfg(feature = "msp430f5513")]
pub mod msp430f5513;
#[cfg(feature = "msp430f5514")]
pub mod msp430f5514;
#[cfg(feature = "msp430f5515")]
pub mod msp430f5515;
#[cfg(feature = "msp430f5517")]
pub mod msp430f5517;
#[cfg(feature = "msp430f5519")]
pub mod msp430f5519;
#[cfg(feature = "msp430f5521")]
pub mod msp430f5521;
#[cfg(feature = "msp430f5522")]
pub mod msp430f5522;
#[cfg(feature = "msp430f5524")]
pub mod msp430f5524;
#[cfg(feature = "msp430f5525")]
pub mod msp430f5525;
#[cfg(feature = "msp430f5526")]
pub mod msp430f5526;
#[cfg(feature = "msp430f5527")]
pub mod msp430f5527;
#[cfg(feature = "msp430f5528")]
pub mod msp430f5528;
#[cfg(feature = "msp430f5529")]
pub mod msp430f5529;
#[cfg(feature = "msp430f5630")]
pub mod msp430f5630;
#[cfg(feature = "msp430f5631")]
pub mod msp430f5631;
#[cfg(feature = "msp430f5632")]
pub mod msp430f5632;
#[cfg(feature = "msp430f5633")]
pub mod msp430f5633;
#[cfg(feature = "msp430f5634")]
pub mod msp430f5634;
#[cfg(feature = "msp430f5635")]
pub mod msp430f5635;
#[cfg(feature = "msp430f5636")]
pub mod msp430f5636;
#[cfg(feature = "msp430f5637")]
pub mod msp430f5637;
#[cfg(feature = "msp430f5638")]
pub mod msp430f5638;
#[cfg(feature = "msp430f5658")]
pub mod msp430f5658;
#[cfg(feature = "msp430f5659")]
pub mod msp430f5659;
#[cfg(feature = "msp430f6433")]
pub mod msp430f6433;
#[cfg(feature = "msp430f6435")]
pub mod msp430f6435;
#[cfg(feature = "msp430f6436")]
pub mod msp430f6436;
#[cfg(feature = "msp430f6438")]
pub mod msp430f6438;
#[cfg(feature = "msp430f6458")]
pub mod msp430f6458;
#[cfg(feature = "msp430f6459")]
pub mod msp430f6459;
#[cfg(feature = "msp430f6630")]
pub mod msp430f6630;
#[cfg(feature = "msp430f6631")]
pub mod msp430f6631;
#[cfg(feature = "msp430f6632")]
pub mod msp430f6632;
#[cfg(feature = "msp430f6633")]
pub mod msp430f6633;
#[cfg(feature = "msp430f6634")]
pub mod msp430f6634;
#[cfg(feature = "msp430f6635")]
pub mod msp430f6635;
#[cfg(feature = "msp430f6636")]
pub mod msp430f6636;
#[cfg(feature = "msp430f6637")]
pub mod msp430f6637;
#[cfg(feature = "msp430f6638")]
pub mod msp430f6638;
#[cfg(feature = "msp430f6658")]
pub mod msp430f6658;
#[cfg(feature = "msp430f6659")]
pub mod msp430f6659;
#[cfg(feature = "msp430f6720")]
pub mod msp430f6720;
#[cfg(feature = "msp430f6720a")]
pub mod msp430f6720a;
#[cfg(feature = "msp430f6721")]
pub mod msp430f6721;
#[cfg(feature = "msp430f6721a")]
pub mod msp430f6721a;
#[cfg(feature = "msp430f6723")]
pub mod msp430f6723;
#[cfg(feature = "msp430f6723a")]
pub mod msp430f6723a;
#[cfg(feature = "msp430f6724")]
pub mod msp430f6724;
#[cfg(feature = "msp430f6724a")]
pub mod msp430f6724a;
#[cfg(feature = "msp430f6725")]
pub mod msp430f6725;
#[cfg(feature = "msp430f6725a")]
pub mod msp430f6725a;
#[cfg(feature = "msp430f6726")]
pub mod msp430f6726;
#[cfg(feature = "msp430f6726a")]
pub mod msp430f6726a;
#[cfg(feature = "msp430f6730")]
pub mod msp430f6730;
#[cfg(feature = "msp430f6730a")]
pub mod msp430f6730a;
#[cfg(feature = "msp430f6731")]
pub mod msp430f6731;
#[cfg(feature = "msp430f6731a")]
pub mod msp430f6731a;
#[cfg(feature = "msp430f6733")]
pub mod msp430f6733;
#[cfg(feature = "msp430f6733a")]
pub mod msp430f6733a;
#[cfg(feature = "msp430f6734")]
pub mod msp430f6734;
#[cfg(feature = "msp430f6734a")]
pub mod msp430f6734a;
#[cfg(feature = "msp430f6735")]
pub mod msp430f6735;
#[cfg(feature = "msp430f6735a")]
pub mod msp430f6735a;
#[cfg(feature = "msp430f6736")]
pub mod msp430f6736;
#[cfg(feature = "msp430f6736a")]
pub mod msp430f6736a;
#[cfg(feature = "msp430f6745")]
pub mod msp430f6745;
#[cfg(feature = "msp430f67451")]
pub mod msp430f67451;
#[cfg(feature = "msp430f67451a")]
pub mod msp430f67451a;
#[cfg(feature = "msp430f6745a")]
pub mod msp430f6745a;
#[cfg(feature = "msp430f6746")]
pub mod msp430f6746;
#[cfg(feature = "msp430f67461")]
pub mod msp430f67461;
#[cfg(feature = "msp430f67461a")]
pub mod msp430f67461a;
#[cfg(feature = "msp430f6746a")]
pub mod msp430f6746a;
#[cfg(feature = "msp430f6747")]
pub mod msp430f6747;
#[cfg(feature = "msp430f67471")]
pub mod msp430f67471;
#[cfg(feature = "msp430f67471a")]
pub mod msp430f67471a;
#[cfg(feature = "msp430f6747a")]
pub mod msp430f6747a;
#[cfg(feature = "msp430f6748")]
pub mod msp430f6748;
#[cfg(feature = "msp430f67481")]
pub mod msp430f67481;
#[cfg(feature = "msp430f67481a")]
pub mod msp430f67481a;
#[cfg(feature = "msp430f6748a")]
pub mod msp430f6748a;
#[cfg(feature = "msp430f6749")]
pub mod msp430f6749;
#[cfg(feature = "msp430f67491")]
pub mod msp430f67491;
#[cfg(feature = "msp430f67491a")]
pub mod msp430f67491a;
#[cfg(feature = "msp430f6749a")]
pub mod msp430f6749a;
#[cfg(feature = "msp430f67621")]
pub mod msp430f67621;
#[cfg(feature = "msp430f67621a")]
pub mod msp430f67621a;
#[cfg(feature = "msp430f67641")]
pub mod msp430f67641;
#[cfg(feature = "msp430f67641a")]
pub mod msp430f67641a;
#[cfg(feature = "msp430f6765")]
pub mod msp430f6765;
#[cfg(feature = "msp430f67651")]
pub mod msp430f67651;
#[cfg(feature = "msp430f67651a")]
pub mod msp430f67651a;
#[cfg(feature = "msp430f6765a")]
pub mod msp430f6765a;
#[cfg(feature = "msp430f6766")]
pub mod msp430f6766;
#[cfg(feature = "msp430f67661")]
pub mod msp430f67661;
#[cfg(feature = "msp430f67661a")]
pub mod msp430f67661a;
#[cfg(feature = "msp430f6766a")]
pub mod msp430f6766a;
#[cfg(feature = "msp430f6767")]
pub mod msp430f6767;
#[cfg(feature = "msp430f67671")]
pub mod msp430f67671;
#[cfg(feature = "msp430f67671a")]
pub mod msp430f67671a;
#[cfg(feature = "msp430f6767a")]
pub mod msp430f6767a;
#[cfg(feature = "msp430f6768")]
pub mod msp430f6768;
#[cfg(feature = "msp430f67681")]
pub mod msp430f67681;
#[cfg(feature = "msp430f67681a")]
pub mod msp430f67681a;
#[cfg(feature = "msp430f6768a")]
pub mod msp430f6768a;
#[cfg(feature = "msp430f6769")]
pub mod msp430f6769;
#[cfg(feature = "msp430f67691")]
pub mod msp430f67691;
#[cfg(feature = "msp430f67691a")]
pub mod msp430f67691a;
#[cfg(feature = "msp430f6769a")]
pub mod msp430f6769a;
#[cfg(feature = "msp430f6775")]
pub mod msp430f6775;
#[cfg(feature = "msp430f67751")]
pub mod msp430f67751;
#[cfg(feature = "msp430f67751a")]
pub mod msp430f67751a;
#[cfg(feature = "msp430f6775a")]
pub mod msp430f6775a;
#[cfg(feature = "msp430f6776")]
pub mod msp430f6776;
#[cfg(feature = "msp430f67761")]
pub mod msp430f67761;
#[cfg(feature = "msp430f67761a")]
pub mod msp430f67761a;
#[cfg(feature = "msp430f6776a")]
pub mod msp430f6776a;
#[cfg(feature = "msp430f6777")]
pub mod msp430f6777;
#[cfg(feature = "msp430f67771")]
pub mod msp430f67771;
#[cfg(feature = "msp430f67771a")]
pub mod msp430f67771a;
#[cfg(feature = "msp430f6777a")]
pub mod msp430f6777a;
#[cfg(feature = "msp430f6778")]
pub mod msp430f6778;
#[cfg(feature = "msp430f67781")]
pub mod msp430f67781;
#[cfg(feature = "msp430f67781a")]
pub mod msp430f67781a;
#[cfg(feature = "msp430f6778a")]
pub mod msp430f6778a;
#[cfg(feature = "msp430f6779")]
pub mod msp430f6779;
#[cfg(feature = "msp430f67791")]
pub mod msp430f67791;
#[cfg(feature = "msp430f67791a")]
pub mod msp430f67791a;
#[cfg(feature = "msp430f6779a")]
pub mod msp430f6779a;
#[cfg(feature = "msp430fe423")]
pub mod msp430fe423;
#[cfg(feature = "msp430fe4232")]
pub mod msp430fe4232;
#[cfg(feature = "msp430fe423a")]
pub mod msp430fe423a;
#[cfg(feature = "msp430fe4242")]
pub mod msp430fe4242;
#[cfg(feature = "msp430fe425")]
pub mod msp430fe425;
#[cfg(feature = "msp430fe4252")]
pub mod msp430fe4252;
#[cfg(feature = "msp430fe425a")]
pub mod msp430fe425a;
#[cfg(feature = "msp430fe427")]
pub mod msp430fe427;
#[cfg(feature = "msp430fe4272")]
pub mod msp430fe4272;
#[cfg(feature = "msp430fe427a")]
pub mod msp430fe427a;
#[cfg(feature = "msp430fg4250")]
pub mod msp430fg4250;
#[cfg(feature = "msp430fg4260")]
pub mod msp430fg4260;
#[cfg(feature = "msp430fg4270")]
pub mod msp430fg4270;
#[cfg(feature = "msp430fg437")]
pub mod msp430fg437;
#[cfg(feature = "msp430fg438")]
pub mod msp430fg438;
#[cfg(feature = "msp430fg439")]
pub mod msp430fg439;
#[cfg(feature = "msp430fg4616")]
pub mod msp430fg4616;
#[cfg(feature = "msp430fg4617")]
pub mod msp430fg4617;
#[cfg(feature = "msp430fg4618")]
pub mod msp430fg4618;
#[cfg(feature = "msp430fg4619")]
pub mod msp430fg4619;
#[cfg(feature = "msp430fg477")]
pub mod msp430fg477;
#[cfg(feature = "msp430fg478")]
pub mod msp430fg478;
#[cfg(feature = "msp430fg479")]
pub mod msp430fg479;
#[cfg(feature = "msp430fg6425")]
pub mod msp430fg6425;
#[cfg(feature = "msp430fg6426")]
pub mod msp430fg6426;
#[cfg(feature = "msp430fg6625")]
pub mod msp430fg6625;
#[cfg(feature = "msp430fg6626")]
pub mod msp430fg6626;
#[cfg(feature = "msp430fr2000")]
pub mod msp430fr2000;
#[cfg(feature = "msp430fr2032")]
pub mod msp430fr2032;
#[cfg(feature = "msp430fr2033")]
pub mod msp430fr2033;
#[cfg(feature = "msp430fr2100")]
pub mod msp430fr2100;
#[cfg(feature = "msp430fr2110")]
pub mod msp430fr2110;
#[cfg(feature = "msp430fr2111")]
pub mod msp430fr2111;
#[cfg(feature = "msp430fr2153")]
pub mod msp430fr2153;
#[cfg(feature = "msp430fr2155")]
pub mod msp430fr2155;
#[cfg(feature = "msp430fr2310")]
pub mod msp430fr2310;
#[cfg(feature = "msp430fr2311")]
pub mod msp430fr2311;
#[cfg(feature = "msp430fr2353")]
pub mod msp430fr2353;
#[cfg(feature = "msp430fr2355")]
pub mod msp430fr2355;
#[cfg(feature = "msp430fr2422")]
pub mod msp430fr2422;
#[cfg(feature = "msp430fr2433")]
pub mod msp430fr2433;
#[cfg(feature = "msp430fr2475")]
pub mod msp430fr2475;
#[cfg(feature = "msp430fr2476")]
pub mod msp430fr2476;
#[cfg(feature = "msp430fr2512")]
pub mod msp430fr2512;
#[cfg(feature = "msp430fr2522")]
pub mod msp430fr2522;
#[cfg(feature = "msp430fr2532")]
pub mod msp430fr2532;
#[cfg(feature = "msp430fr2533")]
pub mod msp430fr2533;
#[cfg(feature = "msp430fr2632")]
pub mod msp430fr2632;
#[cfg(feature = "msp430fr2633")]
pub mod msp430fr2633;
#[cfg(feature = "msp430fr2672")]
pub mod msp430fr2672;
#[cfg(feature = "msp430fr2673")]
pub mod msp430fr2673;
#[cfg(feature = "msp430fr2675")]
pub mod msp430fr2675;
#[cfg(feature = "msp430fr2676")]
pub mod msp430fr2676;
#[cfg(feature = "msp430fr4131")]
pub mod msp430fr4131;
#[cfg(feature = "msp430fr4132")]
pub mod msp430fr4132;
#[cfg(feature = "msp430fr4133")]
pub mod msp430fr4133;
#[cfg(feature = "msp430fr5041")]
pub mod msp430fr5041;
#[cfg(feature = "msp430fr5043")]
pub mod msp430fr5043;
#[cfg(feature = "msp430fr50431")]
pub mod msp430fr50431;
#[cfg(feature = "msp430fr5720")]
pub mod msp430fr5720;
#[cfg(feature = "msp430fr5721")]
pub mod msp430fr5721;
#[cfg(feature = "msp430fr5722")]
pub mod msp430fr5722;
#[cfg(feature = "msp430fr5723")]
pub mod msp430fr5723;
#[cfg(feature = "msp430fr5724")]
pub mod msp430fr5724;
#[cfg(feature = "msp430fr5725")]
pub mod msp430fr5725;
#[cfg(feature = "msp430fr5726")]
pub mod msp430fr5726;
#[cfg(feature = "msp430fr5727")]
pub mod msp430fr5727;
#[cfg(feature = "msp430fr5728")]
pub mod msp430fr5728;
#[cfg(feature = "msp430fr5729")]
pub mod msp430fr5729;
#[cfg(feature = "msp430fr5730")]
pub mod msp430fr5730;
#[cfg(feature = "msp430fr5731")]
pub mod msp430fr5731;
#[cfg(feature = "msp430fr5732")]
pub mod msp430fr5732;
#[cfg(feature = "msp430fr5733")]
pub mod msp430fr5733;
#[cfg(feature = "msp430fr5734")]
pub mod msp430fr5734;
#[cfg(feature = "msp430fr5735")]
pub mod msp430fr5735;
#[cfg(feature = "msp430fr5736")]
pub mod msp430fr5736;
#[cfg(feature = "msp430fr5737")]
pub mod msp430fr5737;
#[cfg(feature = "msp430fr5738")]
pub mod msp430fr5738;
#[cfg(feature = "msp430fr5739")]
pub mod msp430fr5739;
#[cfg(feature = "msp430fr5847")]
pub mod msp430fr5847;
#[cfg(feature = "msp430fr58471")]
pub mod msp430fr58471;
#[cfg(feature = "msp430fr5848")]
pub mod msp430fr5848;
#[cfg(feature = "msp430fr5849")]
pub mod msp430fr5849;
#[cfg(feature = "msp430fr5857")]
pub mod msp430fr5857;
#[cfg(feature = "msp430fr5858")]
pub mod msp430fr5858;
#[cfg(feature = "msp430fr5859")]
pub mod msp430fr5859;
#[cfg(feature = "msp430fr5867")]
pub mod msp430fr5867;
#[cfg(feature = "msp430fr58671")]
pub mod msp430fr58671;
#[cfg(feature = "msp430fr5868")]
pub mod msp430fr5868;
#[cfg(feature = "msp430fr5869")]
pub mod msp430fr5869;
#[cfg(feature = "msp430fr5870")]
pub mod msp430fr5870;
#[cfg(feature = "msp430fr5872")]
pub mod msp430fr5872;
#[cfg(feature = "msp430fr58721")]
pub mod msp430fr58721;
#[cfg(feature = "msp430fr5887")]
pub mod msp430fr5887;
#[cfg(feature = "msp430fr5888")]
pub mod msp430fr5888;
#[cfg(feature = "msp430fr5889")]
pub mod msp430fr5889;
#[cfg(feature = "msp430fr58891")]
pub mod msp430fr58891;
#[cfg(feature = "msp430fr5922")]
pub mod msp430fr5922;
#[cfg(feature = "msp430fr59221")]
pub mod msp430fr59221;
#[cfg(feature = "msp430fr5947")]
pub mod msp430fr5947;
#[cfg(feature = "msp430fr59471")]
pub mod msp430fr59471;
#[cfg(feature = "msp430fr5948")]
pub mod msp430fr5948;
#[cfg(feature = "msp430fr5949")]
pub mod msp430fr5949;
#[cfg(feature = "msp430fr5957")]
pub mod msp430fr5957;
#[cfg(feature = "msp430fr5958")]
pub mod msp430fr5958;
#[cfg(feature = "msp430fr5959")]
pub mod msp430fr5959;
#[cfg(feature = "msp430fr5962")]
pub mod msp430fr5962;
#[cfg(feature = "msp430fr5964")]
pub mod msp430fr5964;
#[cfg(feature = "msp430fr5967")]
pub mod msp430fr5967;
#[cfg(feature = "msp430fr5968")]
pub mod msp430fr5968;
#[cfg(feature = "msp430fr5969")]
pub mod msp430fr5969;
#[cfg(feature = "msp430fr59691")]
pub mod msp430fr59691;
#[cfg(feature = "msp430fr5970")]
pub mod msp430fr5970;
#[cfg(feature = "msp430fr5972")]
pub mod msp430fr5972;
#[cfg(feature = "msp430fr59721")]
pub mod msp430fr59721;
#[cfg(feature = "msp430fr5986")]
pub mod msp430fr5986;
#[cfg(feature = "msp430fr5987")]
pub mod msp430fr5987;
#[cfg(feature = "msp430fr5988")]
pub mod msp430fr5988;
#[cfg(feature = "msp430fr5989")]
pub mod msp430fr5989;
#[cfg(feature = "msp430fr59891")]
pub mod msp430fr59891;
#[cfg(feature = "msp430fr5992")]
pub mod msp430fr5992;
#[cfg(feature = "msp430fr5994")]
pub mod msp430fr5994;
#[cfg(feature = "msp430fr59941")]
pub mod msp430fr59941;
#[cfg(feature = "msp430fr6005")]
pub mod msp430fr6005;
#[cfg(feature = "msp430fr6007")]
pub mod msp430fr6007;
#[cfg(feature = "msp430fr6035")]
pub mod msp430fr6035;
#[cfg(feature = "msp430fr6037")]
pub mod msp430fr6037;
#[cfg(feature = "msp430fr60371")]
pub mod msp430fr60371;
#[cfg(feature = "msp430fr6041")]
pub mod msp430fr6041;
#[cfg(feature = "msp430fr6043")]
pub mod msp430fr6043;
#[cfg(feature = "msp430fr60431")]
pub mod msp430fr60431;
#[cfg(feature = "msp430fr6045")]
pub mod msp430fr6045;
#[cfg(feature = "msp430fr6047")]
pub mod msp430fr6047;
#[cfg(feature = "msp430fr60471")]
pub mod msp430fr60471;
#[cfg(feature = "msp430fr6820")]
pub mod msp430fr6820;
#[cfg(feature = "msp430fr6822")]
pub mod msp430fr6822;
#[cfg(feature = "msp430fr68221")]
pub mod msp430fr68221;
#[cfg(feature = "msp430fr6870")]
pub mod msp430fr6870;
#[cfg(feature = "msp430fr6872")]
pub mod msp430fr6872;
#[cfg(feature = "msp430fr68721")]
pub mod msp430fr68721;
#[cfg(feature = "msp430fr6877")]
pub mod msp430fr6877;
#[cfg(feature = "msp430fr6879")]
pub mod msp430fr6879;
#[cfg(feature = "msp430fr68791")]
pub mod msp430fr68791;
#[cfg(feature = "msp430fr6887")]
pub mod msp430fr6887;
#[cfg(feature = "msp430fr6888")]
pub mod msp430fr6888;
#[cfg(feature = "msp430fr6889")]
pub mod msp430fr6889;
#[cfg(feature = "msp430fr68891")]
pub mod msp430fr68891;
#[cfg(feature = "msp430fr6920")]
pub mod msp430fr6920;
#[cfg(feature = "msp430fr6922")]
pub mod msp430fr6922;
#[cfg(feature = "msp430fr69221")]
pub mod msp430fr69221;
#[cfg(feature = "msp430fr6927")]
pub mod msp430fr6927;
#[cfg(feature = "msp430fr69271")]
pub mod msp430fr69271;
#[cfg(feature = "msp430fr6928")]
pub mod msp430fr6928;
#[cfg(feature = "msp430fr6970")]
pub mod msp430fr6970;
#[cfg(feature = "msp430fr6972")]
pub mod msp430fr6972;
#[cfg(feature = "msp430fr69721")]
pub mod msp430fr69721;
#[cfg(feature = "msp430fr6977")]
pub mod msp430fr6977;
#[cfg(feature = "msp430fr6979")]
pub mod msp430fr6979;
#[cfg(feature = "msp430fr69791")]
pub mod msp430fr69791;
#[cfg(feature = "msp430fr6987")]
pub mod msp430fr6987;
#[cfg(feature = "msp430fr6988")]
pub mod msp430fr6988;
#[cfg(feature = "msp430fr6989")]
pub mod msp430fr6989;
#[cfg(feature = "msp430fr69891")]
pub mod msp430fr69891;
#[cfg(feature = "msp430fw423")]
pub mod msp430fw423;
#[cfg(feature = "msp430fw425")]
pub mod msp430fw425;
#[cfg(feature = "msp430fw427")]
pub mod msp430fw427;
#[cfg(feature = "msp430fw428")]
pub mod msp430fw428;
#[cfg(feature = "msp430fw429")]
pub mod msp430fw429;
#[cfg(feature = "msp430g2001")]
pub mod msp430g2001;
#[cfg(feature = "msp430g2101")]
pub mod msp430g2101;
#[cfg(feature = "msp430g2102")]
pub mod msp430g2102;
#[cfg(feature = "msp430g2111")]
pub mod msp430g2111;
#[cfg(feature = "msp430g2112")]
pub mod msp430g2112;
#[cfg(feature = "msp430g2113")]
pub mod msp430g2113;
#[cfg(feature = "msp430g2121")]
pub mod msp430g2121;
#[cfg(feature = "msp430g2131")]
pub mod msp430g2131;
#[cfg(feature = "msp430g2132")]
pub mod msp430g2132;
#[cfg(feature = "msp430g2152")]
pub mod msp430g2152;
#[cfg(feature = "msp430g2153")]
pub mod msp430g2153;
#[cfg(feature = "msp430g2201")]
pub mod msp430g2201;
#[cfg(feature = "msp430g2202")]
pub mod msp430g2202;
#[cfg(feature = "msp430g2203")]
pub mod msp430g2203;
#[cfg(feature = "msp430g2210")]
pub mod msp430g2210;
#[cfg(feature = "msp430g2211")]
pub mod msp430g2211;
#[cfg(feature = "msp430g2212")]
pub mod msp430g2212;
#[cfg(feature = "msp430g2213")]
pub mod msp430g2213;
#[cfg(feature = "msp430g2221")]
pub mod msp430g2221;
#[cfg(feature = "msp430g2230")]
pub mod msp430g2230;
#[cfg(feature = "msp430g2231")]
pub mod msp430g2231;
#[cfg(feature = "msp430g2232")]
pub mod msp430g2232;
#[cfg(feature = "msp430g2233")]
pub mod msp430g2233;
#[cfg(feature = "msp430g2252")]
pub mod msp430g2252;
#[cfg(feature = "msp430g2253")]
pub mod msp430g2253;
#[cfg(feature = "msp430g2302")]
pub mod msp430g2302;
#[cfg(feature = "msp430g2303")]
pub mod msp430g2303;
#[cfg(feature = "msp430g2312")]
pub mod msp430g2312;
#[cfg(feature = "msp430g2313")]
pub mod msp430g2313;
#[cfg(feature = "msp430g2332")]
pub mod msp430g2332;
#[cfg(feature = "msp430g2333")]
pub mod msp430g2333;
#[cfg(feature = "msp430g2352")]
pub mod msp430g2352;
#[cfg(feature = "msp430g2353")]
pub mod msp430g2353;
#[cfg(feature = "msp430g2402")]
pub mod msp430g2402;
#[cfg(feature = "msp430g2403")]
pub mod msp430g2403;
#[cfg(feature = "msp430g2412")]
pub mod msp430g2412;
#[cfg(feature = "msp430g2413")]
pub mod msp430g2413;
#[cfg(feature = "msp430g2432")]
pub mod msp430g2432;
#[cfg(feature = "msp430g2433")]
pub mod msp430g2433;
#[cfg(feature = "msp430g2444")]
pub mod msp430g2444;
#[cfg(feature = "msp430g2452")]
pub mod msp430g2452;
#[cfg(feature = "msp430g2453")]
pub mod msp430g2453;
#[cfg(feature = "msp430g2513")]
pub mod msp430g2513;
#[cfg(feature = "msp430g2533")]
pub mod msp430g2533;
#[cfg(feature = "msp430g2544")]
pub mod msp430g2544;
#[cfg(feature = "msp430g2553")]
pub mod msp430g2553;
#[cfg(feature = "msp430g2744")]
pub mod msp430g2744;
#[cfg(feature = "msp430g2755")]
pub mod msp430g2755;
#[cfg(feature = "msp430g2855")]
pub mod msp430g2855;
#[cfg(feature = "msp430g2955")]
pub mod msp430g2955;
#[cfg(feature = "msp430i2020")]
pub mod msp430i2020;
#[cfg(feature = "msp430i2021")]
pub mod msp430i2021;
#[cfg(feature = "msp430i2030")]
pub mod msp430i2030;
#[cfg(feature = "msp430i2031")]
pub mod msp430i2031;
#[cfg(feature = "msp430i2040")]
pub mod msp430i2040;
#[cfg(feature = "msp430i2041")]
pub mod msp430i2041;
#[cfg(feature = "msp430l092")]
pub mod msp430l092;
#[cfg(feature = "msp430p112")]
pub mod msp430p112;
#[cfg(feature = "msp430p313")]
pub mod msp430p313;
#[cfg(feature = "msp430p315")]
pub mod msp430p315;
#[cfg(feature = "msp430p315s")]
pub mod msp430p315s;
#[cfg(feature = "msp430p325")]
pub mod msp430p325;
#[cfg(feature = "msp430p337")]
pub mod msp430p337;
#[cfg(feature = "msp430sl5438a")]
pub mod msp430sl5438a;
#[cfg(feature = "msp430tch5e")]
pub mod msp430tch5e;
#[cfg(feature = "rf430f5144")]
pub mod rf430f5144;
#[cfg(feature = "rf430f5155")]
pub mod rf430f5155;
#[cfg(feature = "rf430f5175")]
pub mod rf430f5175;
#[cfg(feature = "rf430frl152h")]
pub mod rf430frl152h;
#[cfg(feature = "rf430frl153h")]
pub mod rf430frl153h;
#[cfg(feature = "rf430frl154h")]
pub mod rf430frl154h;
